@@ -8,7 +8,7 @@ no warnings 'recursion';
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '1.26';
+$VERSION = '1.27';
 
 use base 'Exporter';
 
@@ -104,7 +104,7 @@ sub bigint
 
 $builtin_types{integer} =
  { parse   => \&bigint
- , check   => sub { $_[0] =~ m/^\s*[-+]?\s*\d[\s\d]*$/ }
+ , check   => sub { $_[0] =~ m/^\s*[-+]?\s*[0-9][\s0-9]*$/ }
  , example => 42
  , extends => 'decimal'
  };
@@ -112,7 +112,7 @@ $builtin_types{integer} =
 
 $builtin_types{negativeInteger} =
  { parse   => \&bigint
- , check   => sub { $_[0] =~ m/^\s*\-\s*\d[\s\d]*$/ }
+ , check   => sub { $_[0] =~ m/^\s*\-\s*[0-9][\s0-9]*$/ }
  , example => '-1'
  , extends => 'nonPositiveInteger'
  };
@@ -120,7 +120,7 @@ $builtin_types{negativeInteger} =
 
 $builtin_types{nonNegativeInteger} =
  { parse   => \&bigint
- , check   => sub { $_[0] =~ m/^\s*(?:\+\s*)?\d[\s\d]*$/ }
+ , check   => sub { $_[0] =~ m/^\s*(?:\+\s*)?[0-9][\s0-9]*$/ }
  , example => '17'
  , extends => 'integer'
  };
@@ -128,7 +128,7 @@ $builtin_types{nonNegativeInteger} =
 
 $builtin_types{positiveInteger} =
  { parse   => \&bigint
- , check   => sub { $_[0] =~ m/^\s*(?:\+\s*)?\d[\s\d]*$/ && $_[0] =~ m/[1-9]/ }
+ , check   => sub { $_[0] =~ m/^\s*(?:\+\s*)?[0-9][\s0-9]*$/ && $_[0] =~ m/[1-9]/ }
  , example => '+3'
  , extends => 'nonNegativeInteger'
  };
@@ -136,7 +136,7 @@ $builtin_types{positiveInteger} =
 
 $builtin_types{nonPositiveInteger} =
  { parse   => \&bigint
- , check   => sub { $_[0] =~ m/^\s*(?:\-\s*)?\d[\s\d]*$/
+ , check   => sub { $_[0] =~ m/^\s*(?:\-\s*)?[0-9][\s0-9]*$/
                  || $_[0] =~ m/^\s*(?:\+\s*)0[0\s]*$/ }
  , example => '-42'
  , extends => 'integer'
@@ -146,7 +146,7 @@ $builtin_types{nonPositiveInteger} =
 $builtin_types{long} =
  { parse   => \&bigint
  , check   =>
-     sub { $_[0] =~ m/^\s*[-+]?\s*\d[\s\d]*$/ && ($_[0] =~ tr/0-9//) < 20 }
+     sub { $_[0] =~ m/^\s*[-+]?\s*[0-9][\s0-9]*$/ && ($_[0] =~ tr/0-9//) < 20 }
  , example => '-100'
  , extends => 'integer'
  };
@@ -154,7 +154,7 @@ $builtin_types{long} =
 
 $builtin_types{unsignedLong} =
  { parse   => \&bigint
- , check   => sub {$_[0] =~ m/^\s*\+?\s*\d[\s\d]*$/ && ($_[0] =~ tr/0-9//) < 21}
+ , check   => sub {$_[0] =~ m/^\s*\+?\s*[0-9][\s0-9]*$/ && ($_[0] =~ tr/0-9//) < 21}
  , example => '100'
  , extends => 'nonNegativeInteger'
  };
@@ -162,7 +162,7 @@ $builtin_types{unsignedLong} =
 
 $builtin_types{unsignedInt} =
  { parse   => \&bigint
- , check   => sub {$_[0] =~ m/^\s*\+?\s*\d[\s\d]*$/ && ($_[0] =~ tr/0-9//) <=10}
+ , check   => sub {$_[0] =~ m/^\s*\+?\s*[0-9][\s0-9]*$/ && ($_[0] =~ tr/0-9//) <=10}
  , example => '42'
  , extends => 'unsignedLong'
  };
@@ -173,28 +173,28 @@ $builtin_types{unsignedInt} =
 $builtin_types{non_pos_int} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*[+-]?\s*\d[\d\s]*$/ && $_[0] <= 0}
+ , check   => sub {$_[0] =~ m/^\s*[+-]?\s*[0-9][0-9\s]*$/ && $_[0] <= 0}
  , example => '-12'
  };
 
 $builtin_types{positive_int} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*(?:\+\s*)?\d[\d\s]*$/ }
+ , check   => sub {$_[0] =~ m/^\s*(?:\+\s*)?[0-9][0-9\s]*$/ }
  , example => '+42'
  };
 
 $builtin_types{negative_int} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*\-\s*\d[\d\s]*$/ }
+ , check   => sub {$_[0] =~ m/^\s*\-\s*[0-9][0-9\s]*$/ }
  , example => '-12'
  };
 
 $builtin_types{unsigned_int} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*(?:\+\s*)?\d[\d\s]*$/ && $_[0] >= 0}
+ , check   => sub {$_[0] =~ m/^\s*(?:\+\s*)?[0-9][0-9\s]*$/ && $_[0] >= 0}
  , example => '42'
  };
 
@@ -202,7 +202,7 @@ $builtin_types{unsigned_int} =
 $builtin_types{int} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*[+-]?\d+\s*$/}
+ , check   => sub {$_[0] =~ m/^\s*[+-]?[0-9]+\s*$/}
  , example => '42'
  , extends => 'long'
  };
@@ -212,7 +212,7 @@ $builtin_types{short} =
  { parse   => \&str2int
  , format  => \&int2str
  , check   =>
-    sub { $_[0] =~ m/^\s*[+-]?\d+\s*$/ && $_[0] >= -32768 && $_[0] <= 32767 }
+    sub { $_[0] =~ m/^\s*[+-]?[0-9]+\s*$/ && $_[0] >= -32768 && $_[0] <= 32767 }
  , example => '-7'
  , extends => 'int'
  };
@@ -222,7 +222,7 @@ $builtin_types{unsignedShort} =
  { parse  => \&str2int
  , format => \&int2str
  , check  =>
-    sub { $_[0] =~ m/^\s*[+-]?\d+\s*$/ && $_[0] >= 0 && $_[0] <= 65535 }
+    sub { $_[0] =~ m/^\s*[+-]?[0-9]+\s*$/ && $_[0] >= 0 && $_[0] <= 65535 }
  , example => '7'
  , extends => 'unsignedInt'
  };
@@ -231,7 +231,7 @@ $builtin_types{unsignedShort} =
 $builtin_types{byte} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*[+-]?\d+\s*$/ && $_[0] >= -128 && $_[0] <=127}
+ , check   => sub {$_[0] =~ m/^\s*[+-]?[0-9]+\s*$/ && $_[0] >= -128 && $_[0] <=127}
  , example => '-2'
  , extends => 'short'
  };
@@ -240,7 +240,7 @@ $builtin_types{byte} =
 $builtin_types{unsignedByte} =
  { parse   => \&str2int
  , format  => \&int2str
- , check   => sub {$_[0] =~ m/^\s*[+-]?\d+\s*$/ && $_[0] >= 0 && $_[0] <= 255}
+ , check   => sub {$_[0] =~ m/^\s*[+-]?[0-9]+\s*$/ && $_[0] >= 0 && $_[0] <= 255}
  , example => '2'
  , extends => 'unsignedShort'
  };
@@ -319,14 +319,14 @@ $builtin_types{hexBinary} =
  };
 
 
-my $yearFrag     = qr/ \-? (?: [1-9]\d{3,} | 0\d\d\d ) /x;
+my $yearFrag     = qr/ \-? (?: [1-9][0-9]{3,} | 0[0-9][0-9][0-9] ) /x;
 my $monthFrag    = qr/ 0[1-9] | 1[0-2] /x;
-my $dayFrag      = qr/ 0[1-9] | [12]\d | 3[01] /x;
-my $hourFrag     = qr/ [01]\d | 2[0-3] /x;
-my $minuteFrag   = qr/ [0-5]\d /x;
-my $secondFrag   = qr/ [0-5]\d (?: \.\d+)? /x;
-my $endOfDayFrag = qr/24\:00\:00 (?: \.\d+)? /x;
-my $timezoneFrag = qr/Z | [+-] (?: 0\d | 1[0-4] ) \: $minuteFrag/x;
+my $dayFrag      = qr/ 0[1-9] | [12][0-9] | 3[01] /x;
+my $hourFrag     = qr/ [01][0-9] | 2[0-3] /x;
+my $minuteFrag   = qr/ [0-5][0-9] /x;
+my $secondFrag   = qr/ [0-5][0-9] (?: \.[0-9]+)? /x;
+my $endOfDayFrag = qr/24\:00\:00 (?: \.[0-9]+)? /x;
+my $timezoneFrag = qr/Z | [+-] (?: 0[0-9] | 1[0-4] ) \: $minuteFrag/x;
 my $timeFrag     = qr/ (?: $hourFrag \: $minuteFrag \: $secondFrag )
                      | $endOfDayFrag
                      /x;
@@ -347,7 +347,7 @@ my $time = qr /^ $timeFrag $timezoneFrag? $/x;
 $builtin_types{time} =
  { parse   => \&_collapse
  , format  => sub { return $_[0] if $_[0] =~ /[^0-9.]/;
-      my $subsec = $_[0] =~ /(\.\d+)/ ? $1 : '';
+      my $subsec = $_[0] =~ /(\.[0-9]+)/ ? $1 : '';
       strftime "%T$subsec", gmtime $_[0] }
  , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $time }
  , example => '11:12:13'
@@ -362,7 +362,7 @@ my $dateTimeStamp
 
 sub _dt_format
 {   return $_[0] if $_[0] =~ /[^0-9.]/;  # already formated
-    my $subsec = $_[0] =~ /(\.\d+)/ ? $1 : '';
+    my $subsec = $_[0] =~ /(\.[0-9]+)/ ? $1 : '';
     strftime "%Y-%m-%dT%H:%M:%S${subsec}Z", gmtime $_[0];
 }
 
@@ -432,8 +432,8 @@ $builtin_types{gYearMonth} =
 $builtin_types{duration} =
  { parse   => \&_collapse
  , check   => sub { my $val = $_[0]; $val =~ s/\s+//g;
-      $val =~ m/^\-?P(?:\d+Y)?(?:\d+M)?(?:\d+D)?
-          (?:T(?:\d+H)?(?:\d+M)?(?:\d+(?:\.\d+)?S)?)?$/x }
+      $val =~ m/^\-?P(?:[0-9]+Y)?(?:[0-9]+M)?(?:[0-9]+D)?
+          (?:T(?:[0-9]+H)?(?:[0-9]+M)?(?:[0-9]+(?:\.[0-9]+)?S)?)?$/x }
 
  , example => 'P9M2DT3H5M'
  };
@@ -442,7 +442,7 @@ $builtin_types{duration} =
 $builtin_types{dayTimeDuration} =
  { parse  => \&_collapse
  , check  => sub { my $val = $_[0]; $val =~ s/\s+//g; $val =~
-     m/^\-?P(?:\d+D)?(?:T(?:\d+H)?(?:\d+M)?(?:\d+(?:\.\d+)?S)?)?$/ }
+     m/^\-?P(?:[0-9]+D)?(?:T(?:[0-9]+H)?(?:[0-9]+M)?(?:[0-9]+(?:\.[0-9]+)?S)?)?$/ }
  , example => 'P2DT3H5M10S'
  , extends => 'duration'
  };
@@ -451,7 +451,7 @@ $builtin_types{dayTimeDuration} =
 $builtin_types{yearMonthDuration} =
  { parse  => \&_collapse
  , check  => sub { my $val = $_[0]; $val =~ s/\s+//g; $val =~
-     m/^\-?P(?:\d+Y)?(?:\d+M)?$/ }
+     m/^\-?P(?:[0-9]+Y)?(?:[0-9]+M)?$/ }
  , example => 'P40Y5M'
  , extends => 'duration'
  };
