@@ -8,7 +8,7 @@ no warnings 'recursion';  # trees can be quite deep
 
 package XML::Compile::Translate;
 use vars '$VERSION';
-$VERSION = '1.26';
+$VERSION = '1.27';
 
 
 # Errors are either in _class 'usage': called with request
@@ -648,7 +648,7 @@ sub element($)
       :                            'makeSimpleElement';
 
     my $r = $self->$elem_handler
-      ($where, $tag, ($st||$elems), $attrs, $attrs_any, $comptype);
+       ($where, $tag, ($st||$elems), $attrs, $attrs_any, $comptype);
 
     # Add defaults and stuff
     my $default  = $node->getAttributeNode('default');
@@ -1226,7 +1226,7 @@ sub complexType($)
         if $self->{mixed_elements} eq 'STRUCTURAL';
 
     my $first = $tree->firstChild
-        or return {mixed => $mixed};
+        or return {elems => [], mixed => $mixed};
 
     my $name  = $first->localName;
     return $self->complexBody($tree, $mixed)
